==> vmaid-1.9.3.tar.gz: vmaid-1.9.3/avicore/avifileextra.h <==
/*
    avicore
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __AVI_FILEEXTRA_H__
#define __AVI_FILEEXTRA_H__


#include "avicore.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define AVI_TYPE_FILE_EXTRA            (avi_file_extra_get_type ())
#define AVI_FILE_EXTRA(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), AVI_TYPE_FILE_EXTRA, AviFileExtra))
#define AVI_FILE_EXTRA_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), AVI_TYPE_FILE_EXTRA, AviFileExtraClass))
#define AVI_IS_FILE_EXTRA(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AVI_TYPE_FILE_EXTRA))
#define AVI_IS_FILE_EXTRA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AVI_TYPE_FILE_EXTRA))
#define AVI_FILE_EXTRA_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), AVI_TYPE_FILE_EXTRA, AviFileExtraClass))


typedef struct _AviFileExtra      AviFileExtra;
typedef struct _AviFileExtraClass AviFileExtraClass;

struct _AviFileExtra
{
  /*< private >*/
  GtkVBox parent_instance;

  /*< public >*/
  AviEdit **avi_edit;   /* ja:AVI編集構造体 */

  /*< private >*/
  gint video, audio;    /* ja:ビデオ/オーディオストリームの数 */
  GtkWidget *frame;     /* ja:ビットマップの範囲 */
  GtkWidget *notebook;  /* ja:ストリーム */
  GtkWidget *spin0;     /* ja:ビットマップの開始位置 */
  GtkWidget *spin1;     /* ja:ビットマップの終了位置 */
  GtkWidget *radio0;    /* en:AVI */
  GtkWidget *radio1;    /* ja:ビットマップ */
  GtkWidget *radio2;    /* en:WAVE */
  GtkWidget *radio3;    /* ja:シナリオオブジェクト */
};

struct _AviFileExtraClass
{
  GtkVBoxClass parent_class;
};


/******************************************************************************
*                                                                             *
******************************************************************************/
GType
avi_file_extra_get_type (void) G_GNUC_CONST;


/******************************************************************************
*                                                                             *
* ja:ダイアログ関数                                                           *
*                                                                             *
******************************************************************************/
/*  ja:新規作成
    RET,ウィジェット                                                        */
GtkWidget *
avi_file_extra_new (void);


/*  ja:AVI編集ハンドルを取得する
    fileextra,ウィジェット
          RET,AVI編集ハンドル,NULL:設定なし                                 */
#define avi_file_extra_get_handle(fileextra)                                \
((fileextra)?AVI_FILE_EXTRA(fileextra)->avi_edit:NULL)


/*  ja:AVI編集ハンドルを設定する
     fileextra,ウィジェット
    avi_edit,AVI編集ハンドル,NULL:設定なし                                  */
void
avi_file_extra_set_handle (AviFileExtra  *fileextra,
                           AviEdit      **avi_edit);


/*  ja:保存用のオプションを取得する
    fileextra,ウィジェット
        RET,オプション,NULL:エラー                                          */
AviSave *
avi_file_extra_get_option (AviFileExtra *fileextra);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __AVI_FILESEL_H__ */

==> vmaid-1.9.7.tar.gz: vmaid-1.9.7/avicore/avifileextra.h <==
/*
    avicore
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __AVI_FILEEXTRA_H__
#define __AVI_FILEEXTRA_H__


#include "avicore.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define AVI_TYPE_FILE_EXTRA            (avi_file_extra_get_type ())
#define AVI_FILE_EXTRA(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), AVI_TYPE_FILE_EXTRA, AviFileExtra))
#define AVI_FILE_EXTRA_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), AVI_TYPE_FILE_EXTRA, AviFileExtraClass))
#define AVI_IS_FILE_EXTRA(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AVI_TYPE_FILE_EXTRA))
#define AVI_IS_FILE_EXTRA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AVI_TYPE_FILE_EXTRA))
#define AVI_FILE_EXTRA_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), AVI_TYPE_FILE_EXTRA, AviFileExtraClass))


typedef struct _AviFileExtra      AviFileExtra;
typedef struct _AviFileExtraClass AviFileExtraClass;

struct _AviFileExtra
{
  /*< private >*/
  GtkVBox parent_instance;

  /*< public >*/
  AviEdit **avi_edit;   /* ja:AVI編集構造体 */

  /*< private >*/
  gint video, audio;    /* ja:ビデオ/オーディオストリームの数 */
  GtkWidget *frame;     /* ja:ビットマップの範囲 */
  GtkWidget *notebook;  /* ja:ストリーム */
  GtkWidget *spin0;     /* ja:ビットマップの開始位置 */
  GtkWidget *spin1;     /* ja:ビットマップの終了位置 */
  GtkWidget *radio0;    /* en:AVI */
  GtkWidget *radio1;    /* ja:ビットマップ */
  GtkWidget *radio2;    /* en:WAVE */
  GtkWidget *radio3;    /* ja:シナリオオブジェクト */
};

struct _AviFileExtraClass
{
  GtkVBoxClass parent_class;
};


/******************************************************************************
*                                                                             *
******************************************************************************/
GType
avi_file_extra_get_type (void) G_GNUC_CONST;


/******************************************************************************
*                                                                             *
* ja:ダイアログ関数                                                           *
*                                                                             *
******************************************************************************/
/*  ja:新規作成
    RET,ウィジェット                                                        */
GtkWidget *
avi_file_extra_new (void);


/*  ja:AVI編集ハンドルを取得する
    fileextra,ウィジェット
          RET,AVI編集ハンドル,NULL:設定なし                                 */
#define avi_file_extra_get_handle(fileextra)                                \
((fileextra)?AVI_FILE_EXTRA(fileextra)->avi_edit:NULL)


/*  ja:AVI編集ハンドルを設定する
     fileextra,ウィジェット
    avi_edit,AVI編集ハンドル,NULL:設定なし                                  */
void
avi_file_extra_set_handle (AviFileExtra  *fileextra,
                           AviEdit      **avi_edit);


/*  ja:保存用のオプションを取得する
    fileextra,ウィジェット
        RET,オプション,NULL:エラー                                          */
AviSave *
avi_file_extra_get_option (AviFileExtra *fileextra);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __AVI_FILESEL_H__ */
